@@ -20,6 +20,8 @@
 
 /* #undef GLIB_STATIC_COMPILATION */
 /* #undef GOBJECT_STATIC_COMPILATION */
+/* #undef G_INTL_STATIC_COMPILATION */
+/* #undef FFI_STATIC_BUILD */
 
 G_BEGIN_DECLS
 
@@ -109,22 +111,15 @@ typedef unsigned long guintptr;
 #define G_GUINTPTR_FORMAT       "lu"
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 70
-#define GLIB_MICRO_VERSION 4
+#define GLIB_MINOR_VERSION 74
+#define GLIB_MICRO_VERSION 1
 
 #define G_OS_UNIX
 
 #define G_VA_COPY va_copy
 #define G_VA_COPY_AS_ARRAY 1
 
-
-#ifndef __cplusplus
-# define G_HAVE_ISO_VARARGS 1
-#endif
-
-#ifdef __cplusplus
-# define G_HAVE_ISO_VARARGS 1
-#endif
+#define G_HAVE_ISO_VARARGS 1
 
 /* gcc-2.95.x supports both gnu style and ISO varargs, but if -ansi
  * is passed ISO vararg support is turned off, and there is no work
